@@ -8,16 +8,10 @@ use IPC::Transit::Serialize;
 use vars qw(
     $VERSION
     $config_file $config_dir
+    $local_queues
 );
 
-$VERSION = '0.01';
-
-my $log = sub {
-    my $l = shift;
-    open my $fh, '>>', '/tmp/transit.log';
-    print $fh Dumper $l;
-    close $fh;
-};
+$VERSION = '0.1';
 
 sub
 send {
@@ -38,6 +32,11 @@ send {
     die "IPC::Transit::send: parameter 'message' must be a HASH reference"
         if ref $message ne 'HASH';
 
+    if($local_queues and $local_queues->{$qname}) {
+        push @{$local_queues->{$qname}}, \%args;
+        return \%args;
+    }
+
     eval {
         $args{serialized_message} = IPC::Transit::Serialize::freeze(%args);
     };
@@ -45,6 +44,32 @@ send {
     return $to_queue->snd(1,$args{serialized_message}, IPC::Transit::Internal::_get_flags('nonblocks'));
 }
 
+sub
+stats {
+    my $info = IPC::Transit::Internal::_stats();
+    return $info;
+}
+sub
+stat {
+    my %args;
+    {   my @args = @_;
+        die 'IPC::Transit::stat: even number of arguments required'
+            if scalar @args % 2;
+        %args = @args;
+    }
+    my $qname = $args{qname};
+    if($local_queues and $local_queues->{$qname}) {
+        return {
+            qnum => scalar @{$local_queues->{$qname}}
+        };
+    }
+    die "IPC::Transit::stat: parameter 'qname' required"
+        unless $qname;
+    die "IPC::Transit::stat: parameter 'qname' must be a scalar"
+        if ref $qname;
+    my $info = IPC::Transit::Internal::_stat(%args);
+}
+
 sub
 receive {
     my %args;
@@ -58,8 +83,14 @@ receive {
         unless $qname;
     die "IPC::Transit::receive: parameter 'qname' must be a scalar"
         if ref $qname;
+    if($local_queues and $local_queues->{$qname}) {
+        my $m = shift @{$local_queues->{$qname}};
+        return $m->{message};
+    }
+    my $flags = 0;
+    $flags = IPC::Transit::Internal::_get_flags('nowait') if $args{nonblock};
     my $from_queue = IPC::Transit::Internal::_initialize_queue(%args);
-    my $ret = $from_queue->rcv($args{serialized_data}, 1024000, 1, IPC::Transit::Internal::_get_flags('nowait'));
+    my $ret = $from_queue->rcv($args{serialized_data}, 1024000, 1, $flags);
     return undef unless $args{serialized_data};
     eval {
         $args{message} = IPC::Transit::Serialize::thaw(%args);
@@ -67,6 +98,20 @@ receive {
     return $args{message};
 }
 
+sub
+local_queue {
+    my %args;
+    {   my @args = @_;
+        die 'IPC::Transit::local_queue: even number of arguments required'
+            if scalar @args % 2;
+        %args = @args;
+    }
+    my $qname = $args{qname};
+    $local_queues = {} unless $local_queues;
+    $local_queues->{$qname} = [];
+    return 1;
+}
+
 1;
 
 __END__
@@ -75,8 +120,6 @@ __END__
 
 IPC::Transit - A framework for high performance message passing
 
-** DEVELOPER RELEASE **
-
 =head1 SYNOPSIS
 
   use strict;
@@ -88,14 +131,6 @@ IPC::Transit - A framework for high performance message passing
 
 =head1 DESCRIPTION
 
-** DEVELOPER RELEASE **
-
-This is a proof of concept.
-
-The file and serialization will not be considered set until
-version 0.1.  More to the point, they will DEFINITELY change
-after this release.
-
 This queue framework has the following goals:
 
 =over 4
@@ -130,22 +165,64 @@ This queue framework has the following anti-goals:
 
 =back
 
+=head1 FUNCTIONS
+
+=head2 send(qname => 'some_queue', message => $hashref, serialize_with => 'some serializer')
+
+This sends $hashref to 'some_queue'.  some_queue may be on the local
+box, or it may be in the same process space as the caller.
+
+This call will block until the destination queue has enough space to
+handle the serialized message.
+
+The serialize_with argument is optional, and defaults to Data::Dumper.
+Currently, we are using the module Data::Serializer::Raw; any serialization
+scheme that module supports can be used here.
+
+NB: there is no need to define the serialization type in receive.  It is
+automatically detected and utilized.
+
+=head2 receive(qname => 'some_queue', nonblock => [0|1])
+
+This function fetches a hash reference from 'some_queue' and returns it.
+By default, it will block until a reference is available.  Setting nonblock
+to a true value will cause this to return immediately with 'undef' is
+no messages are available.
+
+
+=head2 stat(qname => 'some_queue')
+
+Returns various stats about the passed queue name, per IPC::Msg::stat:
+
+ print Dumper IPC::Transit::stat(qname => 'test');
+ $VAR1 = {
+          'ctime' => 1335141770,
+          'cuid' => 1000,
+          'lrpid' => 0,
+          'uid' => 1000,
+          'lspid' => 0,
+          'mode' => 438,
+          'qnum' => 0,
+          'cgid' => 1000,
+          'rtime' => 0,
+          'qbytes' => 16384,
+          'stime' => 0,
+          'gid' => 1000
+ }
+
+=head2 stats()
+
+Return an array of hash references, each containing the information 
+obtained by the stat() call, one entry for each queue on the system.
+
 =head1 SEE ALSO
 
 A zillion other queueing systems.
 
-Todo
-
 =head1 TODO
 
-In process delivery.
-
 Cross box delivery.
 
-Arbitrary serialization.
-
-Queue handling facilities.
-
 Much else
 
 =head1 BUGS
